@@ -2,13 +2,14 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.023000';
+$MetaCPAN::Client::Request::VERSION = '1.024000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
 use Search::Elasticsearch;
 use Try::Tiny;
 use HTTP::Tiny;
+use Ref::Util qw< is_hashref >;
 
 has domain => (
     is      => 'ro',
@@ -18,8 +19,21 @@ has domain => (
 );
 
 has version => (
+    is       => 'ro',
+    required => 1,
+    default  => sub {
+        my $info = $_[0]->_clientinfo;
+        $info->{production}{version};
+    },
+);
+
+has _clientinfo => (
     is      => 'ro',
-    default => sub { 'v0' },
+    isa     => sub {
+        is_hashref( $_[0] ) or croak '_clientinfo mush be a hashref';
+    },
+    lazy    => 1,
+    builder => '_build_clientinfo',
 );
 
 has base_url => (
@@ -75,6 +89,25 @@ sub _build_ua {
     return HTTP::Tiny->new( @{ $self->ua_args } );
 }
 
+sub _build_clientinfo {
+    my $self = shift;
+
+    my $info;
+    eval {
+        $info = $self->ua->get( 'https://clientinfo.metacpan.org' );
+        $info = decode_json( $info->{content} );
+        is_hashref($info) and exists $info->{production} or die;
+        1;
+    }
+    or $info = +{
+        production => {
+            version => 'v0'  # last known production version
+        }
+    };
+
+    return $info;
+}
+
 sub fetch {
     my $self    = shift;
     my $url     = shift or croak 'fetch must be called with a URL parameter';
@@ -258,7 +291,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.023000
+version 1.024000
 
 =head1 ATTRIBUTES
 
